xrayutilities.math package
==========================

Submodules
----------

xrayutilities.math.algebra module
---------------------------------

.. automodule:: xrayutilities.math.algebra
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.math.fit module
-----------------------------

.. automodule:: xrayutilities.math.fit
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.math.functions module
-----------------------------------

.. automodule:: xrayutilities.math.functions
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.math.misc module
------------------------------

.. automodule:: xrayutilities.math.misc
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.math.transforms module
------------------------------------

.. automodule:: xrayutilities.math.transforms
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.math.vector module
--------------------------------

.. automodule:: xrayutilities.math.vector
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: xrayutilities.math
    :members:
    :undoc-members:
    :show-inheritance:
